@@ -21,11 +21,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef DOCUMENTLOADINGIMPL_H
 #define DOCUMENTLOADINGIMPL_H
 
-// Qt
-#include <qasyncimageio.h>
-
 // Local 
 #include "documentimpl.h"
+#include "mimetypeutils.h"
+
 namespace Gwenview {
 
 class Document;
@@ -37,12 +36,14 @@ Q_OBJECT
 public:
 	DocumentLoadingImpl(Document* document);
 	~DocumentLoadingImpl();
+	virtual void init();
+	virtual MimeTypeUtils::Kind urlKind() const { return MimeTypeUtils::KIND_RASTER_IMAGE; }
 	
 private:
 	DocumentLoadingImplPrivate* d;
 
 private slots:
-	void start();
+	void slotURLKindDetermined();
 	void sizeLoaded(int, int);
 	void imageChanged(const QRect&);
 	void frameLoaded();
